==> libkysdk-applications_1.2.0.3.orig.tar.gz: libkysdk-applications-1.2.0.3/kysdk-qtwidgets/translations/gui_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>QObject</name>
    <message>
        <source>Cancel</source>
        <translation type="vanished">取消</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="vanished">确定</translation>
    </message>
</context>
<context>
    <name>TestWidget</name>
    <message>
        <source>doing</source>
        <translatorcomment>正在运行...</translatorcomment>
        <translation type="vanished">正在运行...</translation>
    </message>
    <message>
        <source>cancel</source>
        <translatorcomment>取消</translatorcomment>
        <translation type="vanished">取消</translation>
    </message>
    <message>
        <source>Version：2020.1.0</source>
        <translation type="vanished">版本：2020.1.0</translation>
    </message>
</context>
<context>
    <name>kdk::KAboutDialog</name>
    <message>
        <location filename="../src/kaboutdialog.cpp" line="159"/>
        <location filename="../src/kaboutdialog.cpp" line="171"/>
        <source>Service &amp; Support: </source>
        <translatorcomment>服务与支持团队：</translatorcomment>
        <translation>服务与支持团队：</translation>
    </message>
</context>
<context>
    <name>kdk::KInputDialog</name>
    <message>
        <location filename="../src/kinputdialog.cpp" line="206"/>
        <source>Enter a value:</source>
        <translation>请输入数值：</translation>
    </message>
</context>
<context>
    <name>kdk::KInputDialogPrivate</name>
    <message>
        <location filename="../src/kinputdialog.cpp" line="212"/>
        <source>ok</source>
        <translation>确认</translation>
    </message>
    <message>
        <location filename="../src/kinputdialog.cpp" line="214"/>
        <source>cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>kdk::KMenuButton</name>
    <message>
        <location filename="../src/kmenubutton.cpp" line="39"/>
        <source>more</source>
        <translation>更多</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="40"/>
        <source>Setting</source>
        <translatorcomment>设置</translatorcomment>
        <translation>设置</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="41"/>
        <source>Theme</source>
        <translation>主题</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="42"/>
        <source>Assist</source>
        <translation>帮助</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="43"/>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="44"/>
        <source>Quit</source>
        <translation>退出</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="51"/>
        <source>Auto</source>
        <translation>跟随主题</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="53"/>
        <source>Light</source>
        <translation>浅色主题</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="55"/>
        <source>Dark</source>
        <translation>深色主题</translation>
    </message>
</context>
<context>
    <name>kdk::KProgressDialog</name>
    <message>
        <location filename="../src/kprogressdialog.cpp" line="47"/>
        <source>cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>kdk::KSearchLineEdit</name>
    <message>
        <source>Please input searching content</source>
        <translatorcomment>请输入搜索内容</translatorcomment>
        <translation type="vanished">请输入搜索内容</translation>
    </message>
    <message>
        <source>Searching</source>
        <translatorcomment>搜索</translatorcomment>
        <translation type="vanished">搜索</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="vanished">搜索</translation>
    </message>
</context>
<context>
    <name>kdk::KSearchLineEditPrivate</name>
    <message>
        <location filename="../src/ksearchlineedit.cpp" line="206"/>
        <source>search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="../src/ksearchlineedit.cpp" line="279"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
</context>
<context>
    <name>kdk::KSecurityLevelBar</name>
    <message>
        <location filename="../src/ksecuritylevelbar.cpp" line="38"/>
        <source>Low</source>
        <translation>低</translation>
    </message>
    <message>
        <location filename="../src/ksecuritylevelbar.cpp" line="41"/>
        <source>Medium</source>
        <translation>中</translation>
    </message>
    <message>
        <location filename="../src/ksecuritylevelbar.cpp" line="44"/>
        <source>High</source>
        <translation>高</translation>
    </message>
</context>
<context>
    <name>kdk::KSecurityLevelBarPrivate</name>
    <message>
        <location filename="../src/ksecuritylevelbar.cpp" line="110"/>
        <source>Low</source>
        <translation>低</translation>
    </message>
</context>
<context>
    <name>kdk::KTitleBar</name>
    <message>
        <source>minimize</source>
        <translation type="vanished">最小化</translation>
    </message>
    <message>
        <source>maximize</source>
        <translation type="vanished">最大化</translation>
    </message>
    <message>
        <source>close</source>
        <translation type="vanished">关闭</translation>
    </message>
</context>
<context>
    <name>kdk::KUninstallDialog</name>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="102"/>
        <location filename="../src/kuninstalldialog.cpp" line="194"/>
        <source>uninstall</source>
        <translatorcomment>立即卸载</translatorcomment>
        <translation>立即卸载</translation>
    </message>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="163"/>
        <source>deb name:</source>
        <translation>包名：</translation>
    </message>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="168"/>
        <source>deb version:</source>
        <translation>版本：</translation>
    </message>
</context>
<context>
    <name>kdk::KUninstallDialogPrivate</name>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="284"/>
        <source>deb name:</source>
        <translation>包名：</translation>
    </message>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="288"/>
        <source>deb version:</source>
        <translation>版本：</translation>
    </message>
</context>
<context>
    <name>kdk::KWindowButtonBar</name>
    <message>
        <source>minimize</source>
        <translatorcomment>最小化</translatorcomment>
        <translation type="vanished">最小化</translation>
    </message>
    <message>
        <source>maximize</source>
        <translation type="vanished">最大化</translation>
    </message>
    <message>
        <source>close</source>
        <translation type="vanished">关闭</translation>
    </message>
</context>
<context>
    <name>kdk::KWindowButtonBarPrivate</name>
    <message>
        <location filename="../src/kwindowbuttonbar.cpp" line="112"/>
        <source>minimize</source>
        <translation>最小化</translation>
    </message>
    <message>
        <location filename="../src/kwindowbuttonbar.cpp" line="118"/>
        <source>maximize</source>
        <translation>最大化</translation>
    </message>
    <message>
        <location filename="../src/kwindowbuttonbar.cpp" line="123"/>
        <source>close</source>
        <translation>关闭</translation>
    </message>
</context>
</TS>

==> libkysdk-applications_2.0.2.1.orig.tar.gz: libkysdk-applications-2.0.2.1/kysdk-qtwidgets/translations/gui_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>QObject</name>
    <message>
        <source>Cancel</source>
        <translation type="vanished">取消</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="vanished">确定</translation>
    </message>
</context>
<context>
    <name>TestWidget</name>
    <message>
        <source>doing</source>
        <translatorcomment>正在运行...</translatorcomment>
        <translation type="vanished">正在运行...</translation>
    </message>
    <message>
        <source>cancel</source>
        <translatorcomment>取消</translatorcomment>
        <translation type="vanished">取消</translation>
    </message>
    <message>
        <source>Version：2020.1.0</source>
        <translation type="vanished">版本：2020.1.0</translation>
    </message>
</context>
<context>
    <name>kdk::KAboutDialog</name>
    <message>
        <location filename="../src/kaboutdialog.cpp" line="97"/>
        <source>No mail applicaiton accessible in your system.</source>
        <translation>您的系统未安装任何电子邮件应用</translation>
    </message>
    <message>
        <location filename="../src/kaboutdialog.cpp" line="98"/>
        <source>Unable to open mail application</source>
        <translation>无法打开邮件客户端</translation>
    </message>
    <message>
        <location filename="../src/kaboutdialog.cpp" line="230"/>
        <location filename="../src/kaboutdialog.cpp" line="244"/>
        <source>Service &amp; Support: </source>
        <translatorcomment>服务与支持团队：</translatorcomment>
        <translation>服务与支持团队：</translation>
    </message>
    <message>
        <location filename="../src/kaboutdialog.cpp" line="236"/>
        <location filename="../src/kaboutdialog.cpp" line="250"/>
        <source>Privacy statement</source>
        <translation>《隐私声明》</translation>
    </message>
</context>
<context>
    <name>kdk::KInputDialog</name>
    <message>
        <location filename="../src/kinputdialog.cpp" line="220"/>
        <source>Enter a value:</source>
        <translation>请输入数值：</translation>
    </message>
</context>
<context>
    <name>kdk::KInputDialogPrivate</name>
    <message>
        <location filename="../src/kinputdialog.cpp" line="229"/>
        <source>ok</source>
        <translation>确认</translation>
    </message>
    <message>
        <location filename="../src/kinputdialog.cpp" line="231"/>
        <source>cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>kdk::KMenuButton</name>
    <message>
        <source>more</source>
        <translation type="vanished">更多</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="40"/>
        <source>option</source>
        <translation>选项</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="41"/>
        <source>Setting</source>
        <translatorcomment>设置</translatorcomment>
        <translation>设置</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="42"/>
        <source>Theme</source>
        <translation>外观</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="43"/>
        <source>Assist</source>
        <translation>帮助</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="44"/>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="45"/>
        <source>Quit</source>
        <translation>退出</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="52"/>
        <source>Auto</source>
        <translation>跟随系统</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="54"/>
        <source>Light</source>
        <translation>浅色</translation>
    </message>
    <message>
        <location filename="../src/kmenubutton.cpp" line="56"/>
        <source>Dark</source>
        <translation>深色</translation>
    </message>
</context>
<context>
    <name>kdk::KProgressDialog</name>
    <message>
        <location filename="../src/kprogressdialog.cpp" line="48"/>
        <source>cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>kdk::KSearchLineEdit</name>
    <message>
        <source>Please input searching content</source>
        <translatorcomment>请输入搜索内容</translatorcomment>
        <translation type="vanished">请输入搜索内容</translation>
    </message>
    <message>
        <source>Searching</source>
        <translatorcomment>搜索</translatorcomment>
        <translation type="vanished">搜索</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="vanished">搜索</translation>
    </message>
</context>
<context>
    <name>kdk::KSearchLineEditPrivate</name>
    <message>
        <location filename="../src/ksearchlineedit.cpp" line="362"/>
        <source>search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="../src/ksearchlineedit.cpp" line="463"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
</context>
<context>
    <name>kdk::KSecurityLevelBar</name>
    <message>
        <location filename="../src/ksecuritylevelbar.cpp" line="38"/>
        <source>Low</source>
        <translation>低</translation>
    </message>
    <message>
        <location filename="../src/ksecuritylevelbar.cpp" line="41"/>
        <source>Medium</source>
        <translation>中</translation>
    </message>
    <message>
        <location filename="../src/ksecuritylevelbar.cpp" line="44"/>
        <source>High</source>
        <translation>高</translation>
    </message>
</context>
<context>
    <name>kdk::KSecurityLevelBarPrivate</name>
    <message>
        <location filename="../src/ksecuritylevelbar.cpp" line="112"/>
        <source>Low</source>
        <translation>低</translation>
    </message>
</context>
<context>
    <name>kdk::KTitleBar</name>
    <message>
        <source>minimize</source>
        <translation type="vanished">最小化</translation>
    </message>
    <message>
        <source>maximize</source>
        <translation type="vanished">最大化</translation>
    </message>
    <message>
        <source>close</source>
        <translation type="vanished">关闭</translation>
    </message>
</context>
<context>
    <name>kdk::KUninstallDialog</name>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="102"/>
        <location filename="../src/kuninstalldialog.cpp" line="194"/>
        <source>uninstall</source>
        <translatorcomment>立即卸载</translatorcomment>
        <translation>立即卸载</translation>
    </message>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="163"/>
        <source>deb name:</source>
        <translation>包名：</translation>
    </message>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="168"/>
        <source>deb version:</source>
        <translation>版本：</translation>
    </message>
</context>
<context>
    <name>kdk::KUninstallDialogPrivate</name>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="283"/>
        <source>deb name:</source>
        <translation>包名：</translation>
    </message>
    <message>
        <location filename="../src/kuninstalldialog.cpp" line="287"/>
        <source>deb version:</source>
        <translation>版本：</translation>
    </message>
</context>
<context>
    <name>kdk::KWindowButtonBar</name>
    <message>
        <source>minimize</source>
        <translatorcomment>最小化</translatorcomment>
        <translation type="vanished">最小化</translation>
    </message>
    <message>
        <source>maximize</source>
        <translation type="vanished">最大化</translation>
    </message>
    <message>
        <source>close</source>
        <translation type="vanished">关闭</translation>
    </message>
</context>
<context>
    <name>kdk::KWindowButtonBarPrivate</name>
    <message>
        <location filename="../src/kwindowbuttonbar.cpp" line="192"/>
        <source>minimize</source>
        <translation>最小化</translation>
    </message>
    <message>
        <location filename="../src/kwindowbuttonbar.cpp" line="246"/>
        <source>maximize</source>
        <translation>最大化</translation>
    </message>
    <message>
        <location filename="../src/kwindowbuttonbar.cpp" line="251"/>
        <source>restore</source>
        <translation>还原</translation>
    </message>
    <message>
        <location filename="../src/kwindowbuttonbar.cpp" line="201"/>
        <source>close</source>
        <translation>关闭</translation>
    </message>
</context>
</TS>
